<template>
    <div class="form-group">
        <label v-if="label" :for="id" :class="labelClass">
            {{ label }}
        </label>
        <input
            :type="type"
            :id="id"
            :name="name"
            :placeholder="placeholder"
            :class="['form-control', inputClass, { 'is-invalid': errorMessage }]"
            :value="modelValue"
            @input="updateValue"
            :disabled="disabled"
        />
        <span v-if="errorMessage" class="invalid-feedback">{{ errorMessage }}</span>
    </div>
</template>

<script setup>
import { defineProps, defineEmits } from 'vue';

const props = defineProps({
    label: String,
    placeholder: { type: String, default: 'Enter value' },
    name: { type: String, default: '' },
    type: { type: String, default: 'text' },
    id: { type: String, default: '' },
    labelClass: { type: String, default: '' },
    inputClass: { type: String, default: '' },
    modelValue: { type: [String, Number], default: '' },
    errorMessage: { type: String, default: '' },
    disabled: { type: Boolean, default: false }
});

const emit = defineEmits(['update:modelValue']);

const updateValue = (event) => {
    emit('update:modelValue', event.target.value);
};
</script>
